package com.fastbee.iot.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fastbee.deviceData.domain.DeviceRealtimedataMeteorology;
import com.fastbee.deviceData.mapper.DeviceRealtimedataMeteorologyMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.iot.mapper.NgFlowDeviceDataMapper;
import com.fastbee.iot.domain.NgFlowDeviceData;
import com.fastbee.iot.service.INgFlowDeviceDataService;

/**
 * 流量计设备数据Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-12-30
 */
@Service
public class NgFlowDeviceDataServiceImpl extends ServiceImpl<NgFlowDeviceDataMapper, NgFlowDeviceData> implements INgFlowDeviceDataService
{
    @Autowired
    private NgFlowDeviceDataMapper ngFlowDeviceDataMapper;

    /**
     * 查询流量计设备数据
     * 
     * @param id 流量计设备数据主键
     * @return 流量计设备数据
     */
    @Override
    public NgFlowDeviceData selectNgFlowDeviceDataById(Long id)
    {
        return ngFlowDeviceDataMapper.selectNgFlowDeviceDataById(id);
    }

    /**
     * 查询流量计设备数据列表
     * 
     * @param ngFlowDeviceData 流量计设备数据
     * @return 流量计设备数据
     */
    @Override
    public List<NgFlowDeviceData> selectNgFlowDeviceDataList(NgFlowDeviceData ngFlowDeviceData)
    {
        return ngFlowDeviceDataMapper.selectNgFlowDeviceDataList(ngFlowDeviceData);
    }

    /**
     * 新增流量计设备数据
     * 
     * @param ngFlowDeviceData 流量计设备数据
     * @return 结果
     */
    @Override
    public int insertNgFlowDeviceData(NgFlowDeviceData ngFlowDeviceData)
    {
        return ngFlowDeviceDataMapper.insertNgFlowDeviceData(ngFlowDeviceData);
    }

    /**
     * 修改流量计设备数据
     * 
     * @param ngFlowDeviceData 流量计设备数据
     * @return 结果
     */
    @Override
    public int updateNgFlowDeviceData(NgFlowDeviceData ngFlowDeviceData)
    {
        return ngFlowDeviceDataMapper.updateNgFlowDeviceData(ngFlowDeviceData);
    }

    /**
     * 批量删除流量计设备数据
     * 
     * @param ids 需要删除的流量计设备数据主键
     * @return 结果
     */
    @Override
    public int deleteNgFlowDeviceDataByIds(Long[] ids)
    {
        return ngFlowDeviceDataMapper.deleteNgFlowDeviceDataByIds(ids);
    }

    /**
     * 删除流量计设备数据信息
     * 
     * @param id 流量计设备数据主键
     * @return 结果
     */
    @Override
    public int deleteNgFlowDeviceDataById(Long id)
    {
        return ngFlowDeviceDataMapper.deleteNgFlowDeviceDataById(id);
    }
}
